The codes to run the benchmark is located in the repo [MARIO](https://github.com/giovannicatalani/MARIO). Dedicated folders are:
- [`Tensile2d`](https://github.com/giovannicatalani/MARIO/tree/main/Tensile2d_task)
- [`2D_MultiScHypEl`](https://github.com/giovannicatalani/MARIO/tree/main/2D_MultiScHypEl_task)
- [`2D_ElPlDynamics`](https://github.com/giovannicatalani/MARIO/tree/main/2D_ElastoPlastoDynamics_task)
- [`Rotor37`](https://github.com/giovannicatalani/MARIO/tree/main/Rotor37_task)
- [`2D_profile`](https://github.com/giovannicatalani/MARIO/tree/main/2Dprofile_task)
- [`VKI-LS59`](https://github.com/giovannicatalani/MARIO/tree/main/VKILS59_task)
